



pytest --codeblocks
IF %ERRORLEVEL% NEQ 0 exit /B 1
pygalmesh volume-from-surface -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
pygalmesh remesh-surface -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
pygalmesh from-inr -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
